.. :changelog:

History
-------

0.2.0 (2015-07-27)
++++++++++++++++++

* Porting of django-pagination's main paginate function
* Convert to pytest

0.1.0 (2015-07-26)
++++++++++++++++++

* First release on PyPI.
* Inception
